==> base-1.1.28.tar.gz: base/src/Net.h <==
#ifndef _NET_H_INCLUDED_
#define _NET_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// Net.h
// -----
// Base network driver
//                                                         
// (C)opyright 2000-2007 Bjoern Lemke
//
// Design and Implementation by Bjoern Lemke               
//                                                         
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: Net
// 
// Description: All operations on network resources (IPv4)
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

#include "Chain.h"
#include "ListT.h"
#include "NetHandler.h"

class NetHandler;

class Net {

public:
    
    Net(int msgBufSize);
    ~Net();
    
    NetHandler* connect(const Chain& hostname, int port);

    void serve(int port);
    
    NetHandler* nextRequest(int timeout);
    void removeHandle(NetHandler *pN);
    
private:

    int _msgBufSize;
    int _csock;

};



#endif

==> base-1.1.31.tar.gz: base/src/Net.h <==
#ifndef _NET_H_INCLUDED_
#define _NET_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// Net.h
// -----
// Base network driver
//                                                         
// (C)opyright 2000-2007 Bjoern Lemke
//
// Design and Implementation by Bjoern Lemke               
//                                                         
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: Net
// 
// Description: All operations on network resources (IPv4)
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

#include "Chain.h"
#include "ListT.h"
#include "NetHandler.h"

class NetHandler;

class Net {

public:
    
    Net(int msgBufSize, int sizeBufLen);
    ~Net();
    
    NetHandler* connect(const Chain& hostname, int port);

    void serve(int port);
    
    NetHandler* nextRequest(int timeout);
    void removeHandle(NetHandler *pN);
    
private:

    int _msgBufSize;
    int _sizeBufLen;
    
    int _csock;

};



#endif
